@@ -1,8 +1,7 @@
 #' Compute multidimensional difficulty index
 #'
 #' Returns a matrix containing the MDIFF values (Reckase, 2009). Only suppored for items of class
-#' 'dich' and 'graded'. Note that the logistic intercept parameters are divided by 1.702 to match the
-#' normal ogive metric.
+#' 'dich' and 'graded'.
 #'
 #' @aliases MDIFF
 #' @param x an object of class 'SingleGroupClass'
@@ -23,6 +22,9 @@
 #' mod <- mirt(Science, 2)
 #' MDIFF(mod)
 #'
+#' mod <- mirt(expand.table(LSAT7), 2)
+#' MDIFF(mod)
+#'
 #' }
 MDIFF <- function(x, which.items = NULL){
     if(missing(x)) missingMsg('x')
@@ -31,15 +33,15 @@ MDIFF <- function(x, which.items = NULL){
     if(is.null(which.items)) which.items <- 1L:J
     out <- vector('list', length(which.items))
     MD <- MDISC(x)
-    for(i in 1L:length(out)){
+    for(i in seq_len(length(which.items))){
         item <- extract.item(x, which.items[i])
         if(!(class(item) %in% c('dich', 'graded')))
             stop(sprintf('Item %i is not of class \"graded\" or \"dich\"', which.items[i]))
-        ds <- ExtractZetas(item)/1.702
+        ds <- ExtractZetas(item)
         out[[i]] <- -ds / MD[which.items[i]]
     }
     ret <- matrix(NA, length(out), max(sapply(out, length)))
-    for(i in 1L:length(out))
+    for(i in seq_len(length(out)))
         ret[i,1L:length(out[[i]])] <- out[[i]]
     rownames(ret) <- extract.mirt(x, 'itemnames')[which.items]
     colnames(ret) <- paste0('MDIFF_', 1L:ncol(ret))
