@@ -161,6 +161,7 @@ SIBTEST <- function(dat, group, focal_set, match_set, focal_name,
     if(missing(focal_name))
         focal_name <- unique(group)[2L]
     stopifnot(focal_name %in% group)
+    stopifnot(nrow(dat) == length(group))
     group <- ifelse(group == focal_name, 'focal', 'reference')
     stopifnot(!(missing(focal_set) && missing(match_set)))
     index <- 1L:ncol(dat)
@@ -180,26 +181,23 @@ SIBTEST <- function(dat, group, focal_set, match_set, focal_name,
     ref_dat <- dat[group == 'reference',]
     ref_match_scores <- rowSums(ref_dat[,match_set, drop=FALSE])
     ref_suspect_scores <- rowSums(ref_dat[,suspect_set, drop=FALSE])
-    if(pk_focal){
-        tab_scores <- table(rowSums(focal_dat[ ,match_set, drop=FALSE]))
-    } else {
-        tab_scores <- table(rowSums(dat[ ,match_set, drop=FALSE]))
-    }
-    pk <- pkstar <- tab_scores / sum(tab_scores)
-    scores <- as.integer(names(pk))
+    tab_scores <- table(rowSums(dat[ ,match_set, drop=FALSE]))
+    pkstar <- tab_scores / sum(tab_scores)
+    scores <- as.integer(names(pkstar))
 
     # selection
     tab_focal <- tab_ref <- numeric(length(tab_scores))
     II <- tab_scores > Jmin
     tab1 <- table(focal_match_scores)
-    tab2 <- table(ref_match_scores)
     match <- match(names(II), names(tab1), nomatch=0)
     II[match] <- tab1 > Jmin
     tab_focal[match] <- tab1
+    tab2 <- table(ref_match_scores)
     match <- match(names(II), names(tab2), nomatch=0)
     II[match] <- II[match] & tab2 > Jmin
     tab_ref[match] <- tab2
     II <- II & scores != min(scores) & scores != max(scores)
+    II[scores < mean(guess_correction*ncol(dat))] <- FALSE
 
     n <- length(match_set)
     Xbar_ref <- mean(ref_match_scores)
@@ -225,8 +223,17 @@ SIBTEST <- function(dat, group, focal_set, match_set, focal_name,
     Ybar_ref <- ifelse(is.nan(Ybar_ref), 0, Ybar_ref)
     Ybar_focal <- ifelse(is.nan(Ybar_focal), 0, Ybar_focal)
     II <- II & sigma_ref != 0 & sigma_focal != 0
+    if(pk_focal){
+        tmp <- table(rowSums(focal_dat[ ,match_set, drop=FALSE]))
+        tmp <- tmp / sum(tmp)
+        match <- match(names(II), names(tmp), nomatch=0)
+        pkstar[] <- 0
+        pkstar[match] <- tmp
+    }
     pkstar[!II] <- 0
     pkstar <- pkstar / sum(pkstar)
+    tab_focal[tab_focal == 0] <- NA
+    tab_ref[tab_ref == 0] <- NA
     sigma_uni <- sqrt(sum(pkstar^2 * (sigma_focal/tab_focal + sigma_ref/tab_ref), na.rm = TRUE))
     crossvec <- logical(length(II))
     ystar_ref_vec <- ystar_focal_vec <- numeric(length(II))
@@ -281,9 +288,10 @@ SIBTEST <- function(dat, group, focal_set, match_set, focal_name,
     }
     ret <- data.frame(focal_group=focal_name, n_matched_set=length(match_set),
                       n_focal_set = length(focal_set),
-                      beta = beta_uni, z, p = p)
+                      beta = beta_uni, SE=sigma_uni, z, p = p)
     name <- ifelse(cross, 'Crossed_SIBTEST', 'SIBTEST')
     rownames(ret) <- name
+    class(ret) <- c('mirt_df', 'data.frame')
     if(details){
         ret <- data.frame(pkstar=unname(as.numeric(pkstar)),
                           sigma_focal=sigma_focal, sigma_ref=sigma_ref,
