@@ -35,10 +35,15 @@ setMethod(
                 x@OptimInfo$iter, ' ', method, " iterations.\n", sep="")
         cat('mirt version:', as.character(utils::packageVersion('mirt')), '\n')
         cat('M-step optimizer:', x@Options$Moptim, '\n')
-        if(method == 'EM' || method == 'QMCEM' || method == 'BL'){
+        if(method %in% c('EM', 'QMCEM', 'BL', 'MCEM')){
             if(method == 'EM' || method == 'QMCEM')
-                cat('EM acceleration:', x@Options$accelerate)
-            cat('\nNumber of rectangular quadrature:', x@Options$quadpts)
+                cat('EM acceleration:', x@Options$accelerate, '\n')
+            if(method == 'EM' || method == 'BL')
+                cat('Number of rectangular quadrature:', x@Options$quadpts)
+            else if(method == 'QMCEM')
+                cat('Number of quasi-Monte Carlo points:', x@Options$quadpts)
+            else if(method == 'MCEM')
+                cat('Number of Monte Carlo points:', x@Options$quadpts)
             cat('\n')
         }
         if(!is.na(x@OptimInfo$condnum)){
@@ -151,7 +156,7 @@ setMethod(
             gp <- ExtractGroupPars(object@ParObjects$pars[[object@Data$nitems + 1L]])
             Phi <- cov2cor(gp$gcov)
             colnames(h2) <- "h2"
-            rownames(Phi) <- colnames(Phi) <- names(SS) <- colnames(F)[1L:object@Model$nfact]
+            rownames(Phi) <- colnames(Phi) <- names(SS) <- colnames(F)[seq_len(object@Model$nfact)]
             loads <- cbind(F,h2)
             rownames(loads) <- colnames(object@Data$data)
             if(verbose){
@@ -287,7 +292,7 @@ setMethod(
         allPars <- list()
         if(length(object@ParObjects$pars[[1L]]@SEpar)){
             if(printSE){
-                for(i in 1L:(J+1L)){
+                for(i in seq_len(J+1L)){
                     allPars[[i]] <- matrix(c(object@ParObjects$pars[[i]]@par,
                                                    object@ParObjects$pars[[i]]@SEpar),
                                                  2, byrow = TRUE)
@@ -300,7 +305,7 @@ setMethod(
                     colnames(allPars[[i]]) <- nms
                 }
             } else {
-                for(i in 1L:(J+1L)){
+                for(i in seq_len(J+1L)){
                     allPars[[i]] <- matrix(c(object@ParObjects$pars[[i]]@par,
                                                    object@ParObjects$pars[[i]]@par - z*object@ParObjects$pars[[i]]@SEpar,
                                                    object@ParObjects$pars[[i]]@par + z*object@ParObjects$pars[[i]]@SEpar),
@@ -310,7 +315,7 @@ setMethod(
                 }
             }
         } else {
-            for(i in 1L:(J+1L)){
+            for(i in seq_len(J+1L)){
                 allPars[[i]] <- matrix(object@ParObjects$pars[[i]]@par, 1L)
                 colnames(allPars[[i]]) <- names(object@ParObjects$pars[[i]]@est)
                 rownames(allPars[[i]]) <- 'par'
@@ -327,22 +332,22 @@ setMethod(
             allPars <- t(as.data.frame(allPars))
         if(simplify && !as.data.frame){
             allPars <- lapply(allPars, function(x) x[1L, , drop=FALSE])
-            items.old <- allPars[1L:(length(allPars)-1L)]
+            items.old <- allPars[seq_len(length(allPars)-1L)]
             nms <- lapply(items.old, colnames)
             unms <- unique(do.call(c, nms))
             items <- matrix(NA, length(items.old), length(unms))
             rownames(items) <- names(items.old)
             colnames(items) <- unms
-            for(i in 1L:nrow(items))
+            for(i in seq_len(nrow(items)))
                 items[i, nms[[i]]] <- items.old[[i]]
             nfact <- object@Model$nfact
-            means <- allPars$GroupPars[1L:nfact]
+            means <- allPars$GroupPars[seq_len(nfact)]
             if(discrete){
                 allPars <- list(items=items, group.intercepts=allPars$GroupPars)
             } else {
                 covs <- matrix(NA, nfact, nfact)
-                covs[lower.tri(covs, TRUE)] <- allPars$GroupPars[-c(1L:nfact)]
-                colnames(covs) <- rownames(covs) <- names(means) <- object@Model$factorNames[1L:nfact]
+                covs[lower.tri(covs, TRUE)] <- allPars$GroupPars[-seq_len(nfact)]
+                colnames(covs) <- rownames(covs) <- names(means) <- object@Model$factorNames[seq_len(nfact)]
                 allPars <- list(items=items, means=means, cov=covs)
             }
         }
@@ -474,6 +479,8 @@ setMethod(
 #' @param theta_lim range for the integration grid
 #' @param quadpts number of quadrature nodes to use. The default is extracted from model (if available)
 #'   or generated automatically if not available
+#' @param QMC logical; use quasi-Monte Carlo integration? If \code{quadpts} is omitted the
+#'   default number of nodes is 5000
 #' @param suppress a numeric value indicating which parameter local dependency combinations
 #'   to flag as being too high. Absolute values for the standardized estimates greater than
 #'   this value will be returned, while all values less than this value will be set to NA
@@ -510,7 +517,7 @@ setMethod(
 setMethod(
     f = "residuals",
     signature = signature(object = 'SingleGroupClass'),
-    definition = function(object, type = 'LD', df.p = FALSE, full.scores = FALSE,
+    definition = function(object, type = 'LD', df.p = FALSE, full.scores = FALSE, QMC = FALSE,
                           printvalue = NULL, tables = FALSE, verbose = TRUE, Theta = NULL,
                           suppress = 1, theta_lim = c(-6, 6), quadpts = NULL, ...)
     {
@@ -528,17 +535,20 @@ setMethod(
         diag(res) <- NA
         colnames(res) <- rownames(res) <- colnames(data)
         if(!discrete){
-            if(is.null(quadpts))
-                quadpts <- object@Options$quadpts
+            if(is.null(quadpts)){
+                if(QMC) quadpts <- 5000L
+                else quadpts <- object@Options$quadpts
+            }
             if(is.nan(quadpts))
                 quadpts <- select_quadpts(nfact)
-            bfactorlist <- object@Internals$bfactor
             theta <- as.matrix(seq(theta_lim[1L], theta_lim[2L], length.out = quadpts))
             if(type != 'Q3'){
-                if(is.null(bfactorlist$Priorbetween[[1L]])){
-                    Theta <- thetaComb(theta, nfact)
-                } else {
-                    Theta <- object@Model$Theta
+                Theta <- if(QMC)
+                    QMC_quad(npts=quadpts, nfact=nfact, lim=theta_lim)
+                else {
+                    if(nfact > 3L)
+                        warning('High-dimensional models should use QMC integration instead', call.=FALSE)
+                    thetaComb(theta, nfact)
                 }
             } else if(is.null(Theta)){
                 Theta <- fscores(object, verbose=FALSE, full.scores=TRUE, ...)
@@ -554,24 +564,28 @@ setMethod(
         if(type %in% c('LD', 'LDG2')){
             if(!discrete){
                 groupPars <- ExtractGroupPars(object@ParObjects$pars[[object@Data$nitems + 1L]])
-                prior <- mirt_dmvnorm(Theta,groupPars$gmeans, groupPars$gcov)
-                prior <- prior/sum(prior)
+                if(QMC){
+                    prior <- rep(1/nrow(Theta), nrow(Theta))
+                } else {
+                    prior <- mirt_dmvnorm(Theta,groupPars$gmeans, groupPars$gcov)
+                    prior <- prior/sum(prior)
+                }
             } else {
                 prior <- object@Internals$Prior[[1L]]
             }
             df <- (object@Data$K - 1) %o% (object@Data$K - 1)
             diag(df) <- NA
             colnames(df) <- rownames(df) <- colnames(res)
-            for(i in 1L:J){
-                for(j in 1L:J){
+            for(i in seq_len(J)){
+                for(j in seq_len(J)){
                     if(i < j){
                         P1 <- ProbTrace(x=object@ParObjects$pars[[i]], Theta=Theta)
                         P2 <- ProbTrace(x=object@ParObjects$pars[[j]], Theta=Theta)
                         tab <- table(data[,i], data[,j], useNA = 'no')
                         Etab <- matrix(0,K[i],K[j])
                         NN <- sum(tab)
-                        for(k in 1L:K[i])
-                            for(m in 1:K[j])
+                        for(k in seq_len(K[i]))
+                            for(m in seq_len(K[j]))
                                 Etab[k,m] <- NN * sum(P1[,k] * P2[,m] * prior)
                         s <- try(gamma.cor(tab) - gamma.cor(Etab), TRUE)
                         if(is.nan(s) || is(s, 'try-error')){
@@ -644,11 +658,11 @@ setMethod(
         } else if(type == 'Q3'){
             dat <- matrix(NA, N, 2L)
             diag(res) <- 1
-            for(i in 1L:J){
+            for(i in seq_len(J)){
                 ei <- extract.item(object, item=i)
                 EI <- expected.item(ei, Theta=Theta)
                 dat[ ,1L] <- object@Data$data[ ,i] - EI
-                for(j in 1L:J){
+                for(j in seq_len(J)){
                     if(i < j){
                         ej <- extract.item(object, item=j)
                         EJ <- expected.item(ej, Theta=Theta)
@@ -790,7 +804,7 @@ setMethod(
         ThetaFull <- Theta <- thetaComb(theta, nfact)
         prodlist <- attr(x@ParObjects$pars, 'prodlist')
         if(all(x@Data$K[which.items] == 2L) && facet_items) auto.key <- FALSE
-        if(length(prodlist) > 0)
+        if(length(prodlist))
             ThetaFull <- prodterms(Theta,prodlist)
         if(length(degrees) > ncol(ThetaFull)) type <- 'infoangle'
         if(length(degrees) == 1L) degrees <- rep(degrees, ncol(ThetaFull))
@@ -829,7 +843,7 @@ setMethod(
             }, split='\\.')
             imputenums <- do.call(c, tmp)
             CIscore <- CIinfo <- CIrxx <- matrix(0, MI, length(plt$score))
-            for(i in 1L:MI){
+            for(i in seq_len(MI)){
                 while(TRUE){
                     tmp <- try(imputePars(pars=x@ParObjects$pars, pre.ev=pre.ev,
                                           imputenums=imputenums, constrain=x@Model$constrain),
@@ -1088,14 +1102,14 @@ setMethod(
                     tmp <- probtrace(extract.item(x, i), ThetaFull)
                     if(ncol(tmp) == 2L) tmp <- tmp[,2, drop=FALSE]
                     tmp2 <- data.frame(P=as.numeric(tmp), cat=gl(ncol(tmp), k=nrow(Theta),
-                                                           labels=paste0('P', 1L:ncol(tmp))))
+                                                           labels=paste0('P', seq_len(ncol(tmp)))))
                     P[[ind]] <- tmp2
                     ind <- ind + 1L
                 }
                 nrs <- sapply(P, nrow)
                 Pstack <- do.call(rbind, P)
                 names <- c()
-                for(i in 1L:length(nrs))
+                for(i in seq_len(length(nrs)))
                     names <- c(names, rep(names(P)[i], nrs[i]))
                 plotobj <- data.frame(Pstack, item=names, Theta=Theta)
                 plotobj$item <- factor(plotobj$item, levels = colnames(x@Data$data)[which.items])
@@ -1218,7 +1232,7 @@ mirt2traditional <- function(x){
         names(par) <- c('a', paste0('b', 1:(length(par)-1)))
     } else if(cls == 'gpcm'){
         ds <- par[-1]/par[1]
-        ds <- ds[-c(1L:ncat)]
+        ds <- ds[-seq_len(ncat)]
         newd <- numeric(length(ds)-1L)
         for(i in 2:length(ds))
             newd[i-1L] <- -(ds[i] - ds[i-1L])
@@ -1278,8 +1292,8 @@ traditional2mirt <- function(x, cls, ncat, digits = 3){
         par <- c(par[1:(ncat+1)], newd)
         names(par) <- c('a1', paste0('ak', 0:(ncat-1)), paste0('d', 0:(ncat-1)))
     } else if(cls == 'nominal'){
-        as <- x[1L:(length(x)/2)]
-        ds <- x[-c(1L:(length(x)/2))]
+        as <- x[seq_len(length(x)/2)]
+        ds <- x[-seq_len(length(x)/2)]
         a1 <- (as[ncat] - as[1L]) / (ncat-1L)
         ak <- 1:ncat - 1
         for(i in 2:(ncat-1))
