@@ -36,6 +36,9 @@
 #'     infit and outfit statistics. Ignored if models are not from the Rasch family
 #' }
 #'
+#' Note that 'infit', 'S_X2', and 'Zh' cannot be computed when there are missing response data
+#' (i.e., will require multiple-imputation techniques).
+#'
 #' @param which.items an integer vector indicating which items to test for fit.
 #'   Default tests all possible items
 #' @param mincell the minimum expected cell size to be used in the S-X2 computations. Tables will be
@@ -247,7 +250,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
         pv <- fscores(mod, plausible.draws = draws, ...)
         draws <- length(pv)
         df.X2 <- Q1 <- matrix(NA, length(which.items), draws)
-        for (i in 1L:draws) {
+        for (i in seq_len(draws)){
             tmp <- itemfit(mod, fit_stats='X2', which.items=which.items,
                            Theta = pv[[i]], ...)
             Q1[,i] <- tmp$X2
@@ -260,7 +263,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
         ret <- data.frame(PV_Q1=Q1_m, df.PV_Q1=df.X2_m, p.PV_Q1=p.Q1)
         ret
     }
-    boot_PV <- function(mod, org, which.items = 1:extract.mirt(mod, 'nitems'),
+    boot_PV <- function(mod, org, is_NA, which.items = 1:extract.mirt(mod, 'nitems'),
                         boot = 1000, draws = 30, verbose = FALSE, ...){
         pb_fun <- function(ind, mod, N, sv, which.items, draws, ...){
             count <- 0L
@@ -269,6 +272,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
                 if(count == 20)
                     stop('20 consecutive parametric bootstraps failed for PV_Q1*', call.=FALSE)
                 dat <- simdata(model=mod, N=N)
+                dat[is_NA] <- NA
                 mod2 <- mirt(dat, model, itemtype=extract.mirt(mod, 'itemtype'),
                              verbose=FALSE, pars=sv, technical=list(warn=FALSE))
                 if(!extract.mirt(mod2, 'converged')) next
@@ -291,7 +295,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
         ret <- data.frame("p.PV_Q1_star"=Q1)
         ret
     }
-    StoneFit <- function(mod, which.items = 1:extract.mirt(mod, 'nitems'),
+    StoneFit <- function(mod, is_NA, which.items = 1:extract.mirt(mod, 'nitems'),
                          dfapprox = FALSE, boot = 1000, ETrange = c(-2,2), ETpoints = 11,
                          verbose = FALSE, ...){
         X2star <- function(mod, which.items, ETrange, ETpoints, ...){
@@ -304,7 +308,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
             Etable <- Emod@Internals$Etable[[1]]$r1
             itemloc <- extract.mirt(mod, 'itemloc')
             X2 <- rep(NA, ncol(dat))
-            for(i in 1L:length(which.items)){
+            for(i in seq_len(length(which.items))){
                 pick <- itemloc[which.items[i]]:(itemloc[which.items[i]+1L] - 1L)
                 O <- Etable[ ,pick]
                 item <- extract.item(mod, which.items[i])
@@ -313,7 +317,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
             }
             X2[which.items]
         }
-        pb_fun <- function(ind, mod, N, model, itemtype, sv, which.items, ETrange,
+        pb_fun <- function(ind, is_NA, mod, N, model, itemtype, sv, which.items, ETrange,
                            ETpoints, ...){
             count <- 0L
             while(TRUE){
@@ -321,6 +325,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
                 if(count == 20)
                     stop('20 consecutive parametric bootstraps failed for X2*', call.=FALSE)
                 dat <- simdata(model=mod, N=N)
+                dat[is_NA] <- NA
                 mod2 <- mirt(dat, model, itemtype=itemtype, verbose=FALSE, pars=sv,
                              technical=list(warn=FALSE))
                 if(!extract.mirt(mod2, 'converged')) next
@@ -340,7 +345,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
         sv <- mod2values(mod)
         model <- extract.mirt(mod, 'model')
         itemtype <- extract.mirt(mod, 'itemtype')
-        X2bs <- mySapply(1L:boot, pb_fun, mod=mod, N=N, model=model,
+        X2bs <- mySapply(1L:boot, pb_fun, mod=mod, N=N, model=model, is_NA=is_NA,
                          itemtype=itemtype, sv=sv, which.items=which.items,
                          ETrange=ETrange, ETpoints=ETpoints, ...)
         if(nrow(X2bs) == 1L) X2bs <- t(X2bs)
@@ -350,7 +355,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
             upsilon <- 2 * M^2 / V
             gamma <- M / upsilon
             df <- upsilon
-            for(i in 1L:length(which.items)){
+            for(i in seq_len(length(which.items))){
                 item <- extract.item(mod, which.items[i])
                 df[i] <- upsilon[i] - sum(item@est)
             }
@@ -394,20 +399,21 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
     }
     J <- ncol(x@Data$data)
     if(any(is.na(x@Data$data)) && (Zh || S_X2 || infit) && impute == 0)
-        stop('Only X2 and G2 can be computed with missing data. Consider using imputed datasets', call.=FALSE)
+        stop('Only X2, G2, PV_Q1, PV_Q1*, X2*, and X2*_df can be computed with missing data.
+             Consider using imputed datasets', call.=FALSE)
 
     if(is(x, 'MultipleGroupClass') || is(x, 'DiscreteClass')){
         discrete <- is(x, 'DiscreteClass')
         if(discrete)
-            for(g in 1L:x@Data$ngroups)
+            for(g in seq_len(x@Data$ngroups))
                 x@ParObjects$pars[[g]]@ParObjects$pars[[J+1L]]@est[] <- FALSE
         ret <- vector('list', x@Data$ngroups)
         if(is.null(Theta))
             Theta <- fscores(x, method=method, full.scores=TRUE, plausible.draws=impute, ...)
-        for(g in 1L:x@Data$ngroups){
+        for(g in seq_len(x@Data$ngroups)){
             if(impute > 0L){
                 tmpTheta <- vector('list', impute)
-                for(i in 1L:length(tmpTheta))
+                for(i in seq_len(length(tmpTheta)))
                     tmpTheta[[i]] <- Theta[[i]][x@Data$groupNames[g] == x@Data$group, , drop=FALSE]
             } else tmpTheta <- Theta[x@Data$groupNames[g] == x@Data$group, , drop=FALSE]
             tmp_obj <- MGC2SC(x, g)
@@ -448,10 +454,10 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
         pick1 <- 1:nrow(ave)
         pick2 <- sapply(ave, is.numeric)
         ave[pick1, pick2] <- SD[pick1, pick2] <- 0
-        for(i in 1L:impute)
+        for(i in seq_len(impute))
             ave[pick1, pick2] <- ave[pick1, pick2] + collect[[i]][pick1, pick2]
         ave[pick1, pick2] <- ave[pick1, pick2]/impute
-        for(i in 1L:impute)
+        for(i in seq_len(impute))
             SD[pick1, pick2] <- SD[pick1, pick2] + (ave[pick1, pick2] - collect[[i]][pick1, pick2])^2
         SD[pick1, pick2] <- sqrt(SD[pick1, pick2]/impute)
         SD$item <- paste0('SD_', SD$item)
@@ -468,7 +474,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
         infit <- FALSE
         oneslopes <- rep(FALSE, length(x@Model$itemtype))
         slope <- x@ParObjects$pars[[1L]]@par[1L]
-        for(i in 1L:length(x@Model$itemtype))
+        for(i in seq_len(length(x@Model$itemtype)))
             oneslopes[i] <- closeEnough(x@ParObjects$pars[[i]]@par[1L], slope-1e-10, slope+1e-10)
         if(all(oneslopes)) infit <- TRUE
     } else infit <- FALSE
@@ -498,8 +504,8 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
             P <- itemtrace[ ,itemloc[item]:(itemloc[item+1L]-1L)]
             log_P <- log_itemtrace[ ,itemloc[item]:(itemloc[item+1L]-1L)]
             mu[item] <- sum(P * log_P)
-            for(i in 1L:ncol(P))
-                for(j in 1L:ncol(P))
+            for(i in seq_len(ncol(P)))
+                for(j in seq_len(ncol(P)))
                     if(i != j)
                         sigma2[item] <- sigma2[item] + sum(P[,i] * P[,j] *
                                                                log_P[,i] * log(P[,i]/P[,j]))
@@ -532,7 +538,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
         prodlist <- attr(pars, 'prodlist')
         fulldata <- x@Data$fulldata[[1L]]
         if(any(Theta %in% c(Inf, -Inf))){
-            for(i in 1L:ncol(Theta)){
+            for(i in seq_len(ncol(Theta))){
                 tmp <- Theta[,i]
                 tmp[tmp %in% c(-Inf, Inf)] <- NA
                 Theta[Theta[,i] == Inf, i] <- max(tmp, na.rm=TRUE) + .1
@@ -551,7 +557,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
             Groups <- rep(20, length(ord))
             ngroups <- ceiling(nrow(fulldata) / group.size)
             weight <- 1/ngroups
-            for(i in 1L:length(Groups))
+            for(i in seq_len(length(Groups)))
                 Groups[round(cumTheta,2) >= weight*(i-1) & round(cumTheta,2) < weight*i] <- i
         } else {
             ngroups <- group.bins
@@ -702,7 +708,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
         dots <- list(...)
         QMC <- ifelse(is.null(dots$QMC), FALSE, dots$QMC)
         quadpts <- dots$quadpts
-        if(is.null(quadpts) && QMC) quadpts <- 15000L
+        if(is.null(quadpts) && QMC) quadpts <- 5000L
         if(is.null(quadpts)) quadpts <- select_quadpts(x@Model$nfact)
         if(x@Model$nfact > 3L && !QMC && method %in% c('EAP', 'EAPsum') && !discrete)
             warning('High-dimensional models should use quasi-Monte Carlo integration. Pass QMC=TRUE',
@@ -719,7 +725,7 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
         if(S_X2.tables) return(list(O.org=O, E.org=E, O=coll$O, E=coll$E))
         O <- coll$O
         E <- coll$E
-        for(i in 1L:J){
+        for(i in seq_len(J)){
             if (is.null(dim(O[[i]])) || is.null(E[[i]])) next
             S_X2[i] <- sum((O[[i]] - E[[i]])^2 / E[[i]], na.rm = TRUE)
             df.S_X2[i] <- sum(!is.na(E[[i]])) - nrow(E[[i]]) - sum(pars[[i]]@est)
@@ -735,17 +741,19 @@ itemfit <- function(x, fit_stats = 'S_X2', which.items = 1:extract.mirt(x, 'nite
         tmp <- PV_itemfit(x, which.items=which.items, draws=pv_draws, ...)
         ret <- cbind(ret, tmp)
     }
+    is_NA <- is.na(x@Data$data)
     if('PV_Q1*' %in% fit_stats){
-        tmp <- boot_PV(x, org=tmp, which.items=which.items, boot=boot, draws=pv_draws, ...)
+        tmp <- boot_PV(x, is_NA=is_NA, org=tmp, which.items=which.items,
+                       boot=boot, draws=pv_draws, ...)
         ret <- cbind(ret, tmp)
     }
     if('X2*' %in% fit_stats){
-        tmp <- StoneFit(x, which.items=which.items, boot=boot, dfapprox=FALSE,
+        tmp <- StoneFit(x, is_NA=is_NA, which.items=which.items, boot=boot, dfapprox=FALSE,
                  ETrange=ETrange, ETpoints=ETpoints, ...)
         ret <- cbind(ret, tmp)
     }
     if('X2*_df' %in% fit_stats){
-        tmp <- StoneFit(x, which.items=which.items, boot=boot_dfapprox, dfapprox=TRUE,
+        tmp <- StoneFit(x, is_NA=is_NA, which.items=which.items, boot=boot_dfapprox, dfapprox=TRUE,
                         ETrange=ETrange, ETpoints=ETpoints, ...)
         ret <- cbind(ret, tmp)
     }
