@@ -82,11 +82,13 @@ test_that('dich', {
     mod <- mirt(dat, 1, method = 'QMCEM', verbose=FALSE, optimizer='NR')
     expect_equal(extract.mirt(mod, 'logLik'), -2466.653, tolerance=1e-4)
     fs <- fscores(mod, QMC=TRUE, verbose=FALSE, full.scores=FALSE)
-    expect_equal(fs[1:3,'F1'], c(-1.8971, -1.4750, -1.4547), tolerance=1e-4)
+    expect_equal(fs[1:3,'F1'], c(-1.887714, -1.473829, -1.453797), tolerance=1e-4)
     m2 <- M2(mod, QMC=TRUE)
-    expect_equal(m2$M2, 4.737918, tolerance=1e-5)
+    expect_equal(m2$M2, 4.737141, tolerance=1e-5)
     ifit <- itemfit(mod, QMC=TRUE)
-    expect_equal(ifit$p.S_X2[1], .7985, tolerance = 1e-2)
+    expect_equal(ifit$p.S_X2[1], .7984, tolerance = 1e-2)
+    rfit <- residuals(mod, QMC=TRUE, verbose=FALSE)
+    expect_equal(as.numeric(rfit[,1]), c(NA, 0.0468866, 0.3906001, -0.2476980, -0.5195561), tolerance = 1e-2)
 
     fm1 <- fscores(modm1, verbose = FALSE, full.scores=FALSE)
     expect_is(fm1, 'matrix')
